==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>ロード/セーブ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>オートセーブ</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>オートセーブ中:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>オートセーブ失敗:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>オートセーブ完了。</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>無題の図面のオートセーブバックアップファイルが見つかりました。
これを回復しますか？</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>%1 図面のオートセーブバックアップファイルが見つかりました。
これを回復しますか？</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Recover Files?</source>
        <translation>ファイルを回復しますか？</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>回復しました</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>ファイルを回復しますか？</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>%1 オートセーブバックアップファイルは存在します。
これを回復しますか？</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>ファイルをリネームできません:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>移動されたオートセーブバックアップファイル:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>オリジナルファイルは移動されました:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>ファイルを移動できません:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>オートセーブ可能にする</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>オートセーブ間隔:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>分</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">ロード/セーブ</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>オートセーブ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>オートセーブ中:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>オートセーブ失敗:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>オートセーブ完了。</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">無題の図面のオートセーブバックアップファイルが見つかりました。
これを回復しますか？</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">%1 図面のオートセーブバックアップファイルが見つかりました。
これを回復しますか？</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Recover Files?</source>
        <translation>ファイルを回復しますか？</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>回復しました</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>ファイルを回復しますか？</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>%1 オートセーブバックアップファイルは存在します。
これを回復しますか？</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>ファイルをリネームできません:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>移動されたオートセーブバックアップファイル:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>オリジナルファイルは移動されました:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>ファイルを移動できません:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>オートセーブ可能にする</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>オートセーブ間隔:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>分</translation>
    </message>
</context>
</TS>
